==> skill-admin-home-18.0.0-sources.jar: com/ptteng/controller/RecordParam/RecordParam.java <==
package com.ptteng.controller.RecordParam;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by J.w on 2018/3/29.
 * 功能描述：
 */
public class RecordParam {

    private Long id;
    private Long uid;
    private String name;
    private String occupation;
    private String branch;
    private String startAt;
    private String graduateAt;
    private String grade;
    private String school;
    private String schoolType;
    private String major;
    private String source;
    private String status;
    private String recordStatus;
    private String companyName;
    private String salary;

    private final Map<String, String> config = new HashMap<>();
    private final String[] keys = new String[]{"uid", "name", "branch", "startAt", "graduateAt", "grade", "schoolType",
            "school", "major", "source", "status", "recordStatus", "companyName", "salary"};

    public RecordParam() {
        config.put("uid", "ID");
        config.put("name", "昵称");
        config.put("branch", "分院");
        config.put("startAt", "入学时间");
        config.put("graduateAt", "结业时间");
        config.put("grade", "学历");
        config.put("schoolType", "211/985");
        config.put("school", "毕业院校");
        config.put("major", "专业");
        config.put("source", "报名渠道");
        config.put("status", "状态");
        config.put("recordStatus", "档案状态");
        config.put("companyName", "公司名称");
        config.put("salary", "薪资待遇");
    }

    public Map<String, String> getConfig() {
        return config;
    }

    public String[] getKeys() {
        return keys;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getOccupation() {
        return occupation;
    }

    public void setOccupation(String occupation) {
        this.occupation = occupation;
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }

    public String getStartAt() {
        return startAt;
    }

    public void setStartAt(String startAt) {
        this.startAt = startAt;
    }

    public String getGraduateAt() {
        return graduateAt;
    }

    public void setGraduateAt(String graduateAt) {
        this.graduateAt = graduateAt;
    }

    public String getGrade() {
        return grade;
    }

    public void setGrade(String grade) {
        this.grade = grade;
    }

    public String getSchool() {
        return school;
    }

    public void setSchool(String school) {
        this.school = school;
    }

    public String getSchoolType() {
        return schoolType;
    }

    public void setSchoolType(String schoolType) {
        this.schoolType = schoolType;
    }

    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getSalary() {
        return salary;
    }

    public void setSalary(String salary) {
        this.salary = salary;
    }

    public String getRecordStatus() {
        return recordStatus;
    }

    public void setRecordStatus(String recordStatus) {
        this.recordStatus = recordStatus;
    }
}

==> skill-admin-home-25.0.4-sources.jar: com/ptteng/controller/RecordParam/RecordParam.java <==
package com.ptteng.controller.RecordParam;

import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by J.w on 2018/3/29.
 * 功能描述：
 */
public class RecordParam {

    private Long id;
    private Long uid;
    private String name;
    private String occupation;
    private String branch;
    private String startAt;
    private String graduateAt;
    private String grade;
    private String school;
    private String schoolType;
    private String major;
    private String source;
    private String status;
    private String recordStatus;
    private String companyName;
    private String salary;

    private final Map<String, String> config = new HashMap<>();
    private final String[] keys = new String[]{"uid", "name","occupation", "branch", "startAt", "graduateAt", "grade", "schoolType",
            "school", "major", "source", "status", "recordStatus", "companyName", "salary"};

    public RecordParam() {
        config.put("uid", "ID");
        config.put("name", "昵称");
        config.put("occupation", "职业");
        config.put("branch", "分院");
        config.put("startAt", "入学时间");
        config.put("graduateAt", "结业时间");
        config.put("grade", "学历");
        config.put("schoolType", "211/985");
        config.put("school", "毕业院校");
        config.put("major", "专业");
        config.put("source", "报名渠道");
        config.put("status", "状态");
        config.put("recordStatus", "档案状态");
        config.put("companyName", "公司名称");
        config.put("salary", "薪资待遇");
    }

    public Map<String, String> getConfig() {
        return config;
    }

    public String[] getKeys() {
        return keys;
    }

    public String toString() {
        return ToStringBuilder.reflectionToString(this,
                ToStringStyle.MULTI_LINE_STYLE);
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getOccupation() {
        return occupation;
    }

    public void setOccupation(String occupation) {
        this.occupation = occupation;
    }

    public String getBranch() {
        return branch;
    }

    public void setBranch(String branch) {
        this.branch = branch;
    }

    public String getStartAt() {
        return startAt;
    }

    public void setStartAt(String startAt) {
        this.startAt = startAt;
    }

    public String getGraduateAt() {
        return graduateAt;
    }

    public void setGraduateAt(String graduateAt) {
        this.graduateAt = graduateAt;
    }

    public String getGrade() {
        return grade;
    }

    public void setGrade(String grade) {
        this.grade = grade;
    }

    public String getSchool() {
        return school;
    }

    public void setSchool(String school) {
        this.school = school;
    }

    public String getSchoolType() {
        return schoolType;
    }

    public void setSchoolType(String schoolType) {
        this.schoolType = schoolType;
    }

    public String getMajor() {
        return major;
    }

    public void setMajor(String major) {
        this.major = major;
    }

    public String getSource() {
        return source;
    }

    public void setSource(String source) {
        this.source = source;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getSalary() {
        return salary;
    }

    public void setSalary(String salary) {
        this.salary = salary;
    }

    public String getRecordStatus() {
        return recordStatus;
    }

    public void setRecordStatus(String recordStatus) {
        this.recordStatus = recordStatus;
    }
}
